##The Appointment of Men to the United Nation's Commission on the Status of Women
#Elizabeth Brannon

#Replication file

#Packages
library(ggplot2)
library(arm)
library(MASS)
library(faraway)
library(naniar)
library(dplyr)
library(ggfortify)
library(Hmisc)
library(survival)
library(ranger)
library(DataCombine)

#Load Data

#Omit NA's to calculate predicted probs later
rep.data <- data[,c("Country", "ccode", "Year", "RepGender", "wpe.index", "wpe.index2",  "effective_quota",  "loggdppc", "democracy", "sumigo", "Fertility", "Workforce_part")]
rep.data <- na.omit(rep.data)

#Main Model 


rep.model <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                 + effective_quota + Workforce_part + Fertility+ sumigo, 
                 data=rep.data, family=binomial(link=logit))
summary(rep.model)


#Predicted Probabilities
n.draws <- 100
sq<-seq(from=min(na.omit(rep.data$wpe.index)), to=max(na.omit(rep.data$wpe.index)), length.out=100)

sim.fem.mem <- coef(sim(rep.model, n = 100))

# Empty vectors to store the point estimates and confidence intervals
pe.ov <- as.matrix(NA, nrow=length(sq)) 
lo.ov <- as.matrix(NA, nrow=length(sq)) 
hi.ov <- as.matrix(NA, nrow=length(sq)) 

pe.ov.change <- as.matrix(NA, nrow=length(sq)) 
lo.ov.change <- as.matrix(NA, nrow=length(sq)) 
hi.ov.change <- as.matrix(NA, nrow=length(sq)) 


for(j in 1:length(sq)){ # Loop goes across distance values
  # Set the other independent variables to all of their observed values
  coef(rep.model)
  x.distance <- data.frame(intercept = 1,
                           wpe.index=sq[j],
                           wpe.index2=sq[j]^2,
                           democracy=rep.data$democracy,
                           loggdppc=rep.data$loggdppc,
                           effective_quota=rep.data$effective_quota,
                           Workforce_part=rep.data$Workforce_part,
                           Fertility=rep.data$Fertility,
                           sumigo=rep.data$sumigo)
  
  x.distance <-data.matrix(x.distance)
  
  # Save average of linear predictor across all the observations
  pp<-matrix(NA, nrow=n.draws)
  pp.change<-matrix(NA, nrow=n.draws)
  
  for(i in 1:n.draws){# Loop over coefficients
    # For each observation in the dataset
    xb<- ilogit(x.distance%*%(sim.fem.mem[i,]))
    pp[i]<-mean(xb)
  }
  dim(sim.fem.mem)
  dim(x.distance)
  # Compute point estimate and CI for each value of distance
  pe.ov[j] <- quantile(pp, 0.5)
  lo.ov[j] <- quantile(pp, 0.025) 
  hi.ov[j] <- quantile(pp, 0.975)
  
} 

plot(sq, pe.ov, xlab="Women's Political Empowerment Index", 
     type='l', 
     ylab="P(Appointing a Woman Representative)",
     xlim=c(.2,.95),
     ylim=c(.25,.8),
     cex.lab=1.25, cex.axis=1)
lines(sq, lo.ov, lty=2)
lines(sq, hi.ov, lty=2)
rug(rep.data$wpe.index, ticksize = 0.03, lwd = 0.5)
dev.off()

#Alternate Explanations

#Time

rep.model.time <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                      + effective_quota + Workforce_part + Fertility+ sumigo + V2 + V3 +V4, 
                      data=rep.data, family=binomial(link=logit))
summary(rep.model.time)


#Audience costs

rep.model.lagged <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                        + effective_quota + Workforce_part + Fertility+ sumigo + RepGender.lagged + RepGender.lagged:democracy, 
                        data=rep.data, family=binomial(link=logit))
summary(rep.model.lagged)

rep.model.lagged2 <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                         + effective_quota + Workforce_part + Fertility+ sumigo + last3, 
                         data=rep.data, family=binomial(link=logit))
summary(rep.model.lagged2)

#Women's Mobilization 
rep.model.wingos <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                        + effective_quota + Workforce_part + Fertility+ sumigo + wingos, 
                        data=rep.data, family=binomial(link=logit))
summary(rep.model.wingos)

#Women's Conference
rep.model.conf <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                      + effective_quota + Workforce_part + Fertility+ sumigo + wom_conf, 
                      data=rep.data, family=binomial(link=logit))
summary(rep.model.conf)

#Executive Interests
rep.model.cab <- glm(RepGender~wpe.index + wpe.index2 + democracy + loggdppc  
                     + effective_quota + Workforce_part + Fertility+ sumigo + fem_cab, 
                     data=rep.data, family=binomial(link=logit))
summary(rep.model.cab)


##Robustness Checks

#Participation Model

#Load Participation Data

#Omit NAs to run predicted probabilities later
part.data <- na.omit(part.data)

part.model <- glm(Participation~wpe.index + wpe.index2 + democracy + loggdppc  
                  + effective_quota + Workforce_part + Fertility+ sumigo, 
                  data=part.data, family=binomial(link=logit))
summary(part.model)


n.draws<-100
part.sim<-coef(sim(part.model, n.draws))
sq<-seq(from=min(na.omit(part.data$wpe.index)), to=max(na.omit(part.data$wpe.index)), length.out=100)
sq.x.lo<-data.frame(
  intercept=1,
  wpe.index=0.35,
  wpe.index2=0.1225,
  democracy=part.data$democracy,
  loggdppc=part.data$loggdppc,
  effective_quota=part.data$effective_quota,
  Workforce_part=part.data$Workforce_part,
  Fertility=part.data$Fertility,
  sumigo=part.data$sumigo)

sq.x.hi<-data.frame(
  intercept=1,
  wpe.index=0.75,
  wpe.index2=0.5625,
  democracy=part.data$democracy,
  loggdppc=part.data$loggdppc,
  effective_quota=part.data$effective_quota,
  Workforce_part=part.data$Workforce_part,
  Fertility=part.data$Fertility,
  sumigo=part.data$sumigo)

pe.x.hi <- as.matrix(NA, nrow= n.draws)
pe.x.lo <- as.matrix(NA, nrow= n.draws)

hi.x.hi <- as.matrix(NA, nrow= n.draws)
hi.x.lo <- as.matrix(NA, nrow= n.draws)

lo.x.hi <- as.matrix(NA, nrow= n.draws)
lo.x.lo <- as.matrix(NA, nrow= n.draws)

dif.x <- as.matrix(NA, nrow= n.draws)


sq.x.hi <- as.matrix(sq.x.hi)
sq.x.lo <- as.matrix(sq.x.lo)
#Fill the vectors


for(j in 1:n.draws){
  pe.x.hi[j] <- mean(ilogit(sq.x.hi %*% part.sim[j,]), na.rm=T)
  pe.x.lo[j] <- mean(ilogit(sq.x.lo %*% part.sim[j,]), na.rm=T)
  
  
  #first differences
  dif.x[j] <- pe.x.hi[j] - pe.x.lo[j]
}

dif.fun <- function(x) {
  result <- c(quantile(x, 0.025), mean(x), quantile(x,.975))
  return(result)
}
pe.x.hi <- dif.fun(pe.x.hi)
pe.x.lo <- dif.fun(pe.x.lo)

dif.x <- dif.fun(dif.x)

preds <- as.data.frame(rbind(pe.x.hi
                             ,pe.x.lo
                             ,dif.x))
rownames(preds) <- c("High WPE", 'Low WPE', 'Change in Probability')
preds$levels <- rownames(preds)
preds$levels <- factor(preds$levels, levels=unique(preds$levels))

#Figure
ggplot() + 
  geom_point(data = preds
             ,aes(x=preds$levels, y=preds$V2)
             ,size = 4
             ,color = "black") + 
  geom_segment(aes(x = preds$levels
                   , y = preds$`2.5%`
                   , xend = preds$levels
                   , yend = preds$`97.5%`)
               , color = "black"
               , size = 1
               , data = preds
               , lty= c(1,1,6)) +
  geom_hline(aes(yintercept=0), color = "black", lty=2) + 
  theme_bw() + coord_flip() + 
  theme(axis.text = element_text(size=13), axis.title=element_text(size=14), panel.grid.major = element_blank(), panel.grid.minor = element_blank(), aspect.ratio=1) +
  xlab('') + 
  ylab('Probability of Participation in the CSW')  #No significance 


#Alt Operationalizations & Controls

#load full data again 

#Women's Representation

rep.model.womrep <- glm(RepGender~Per_Fem + Per_Fem2 + democracy + loggdppc  
                     + effective_quota + Workforce_part + Fertility+ sumigo, 
                     data=rep.data, family=binomial(link=logit))
summary(rep.model.womrep)


rep.model.CL <- glm(RepGender~wpe.index + wpe.index2 + FH_CL + loggdppc  
                    + effective_quota + Workforce_part + Fertility+ sumigo, 
                    data=rep.data, family=binomial(link=logit))
summary(rep.model.CL)

rep.model.PR <- glm(RepGender~wpe.index + wpe.index2 + FH_PR + loggdppc  
                    + effective_quota + Workforce_part + Fertility+ sumigo, 
                    data=rep.data, family=binomial(link=logit))
summary(rep.model.PR)







